@@ -125,7 +125,8 @@ class Forum extends Error {
 			$this->setError(_('Forum Description Must Be At Least 10 Characters'));
 			return false;
 		}
-		if (preg_match('[^_\.0-9a-z-]',$forum_name)) {
+		$forum_name = strtolower($forum_name);
+		if (!preg_match('/^([_\.0-9a-z-])*$/i',$forum_name)) {
 			$this->setError(_('Illegal Characters in Forum Name'));
 			return false;
 		}
@@ -170,7 +171,7 @@ class Forum extends Error {
 		db_begin();
 		$result = db_query_params('INSERT INTO forum_group_list (group_id,forum_name,is_public,description,send_all_posts_to,allow_anonymous,moderation_level) VALUES ($1,$2,$3,$4,$5,$6,$7)',
 					  array ($this->Group->getID(),
-						 strtolower($forum_name),
+						 $forum_name,
 						 $is_public,
 						 htmlspecialchars($description),
 						 $send_all_posts_to,
@@ -183,6 +184,22 @@ class Forum extends Error {
 		}
 		$this->group_forum_id=db_insertid($result,'forum_group_list','group_forum_id');
 		$this->fetchData($this->group_forum_id);
+		
+		// set the permission for the role's group 
+		$roles_group = $this->Group->getRolesId();
+		for ($i=0; $i<sizeof($roles_group); $i++) {
+			$role_setting_res = db_query_params ('INSERT INTO role_setting (role_id,section_name,ref_id,value) VALUES ($1,$2,$3,$4)',
+						array ($roles_group[$i],
+						       'forum',
+						       $this->group_forum_id,
+						       1)) ;
+			if (!$role_setting_res) {
+				db_rollback();
+				$this->setError('Error: Role setting for forum id ' . $this->group_forum_id . ' for groud id ' . $this->Group->getID() . ' ' .db_error());
+				return false;
+			}
+		}
+		
 		if ($create_default_message) {
 			$fm=new ForumMessage($this);
 			// Use the system side default language
@@ -576,7 +593,8 @@ class Forum extends Error {
 			$this->setError(_('Forum Description Must Be At Least 10 Characters'));
 			return false;
 		}
-		if (eregi('[^_\.0-9a-z-]',$forum_name)) {
+		$forum_name = strtolower($forum_name);
+		if (!preg_match('/^([_\.0-9a-z-])*$/',$forum_name)) {
 			$this->setError(_('Illegal Characters in Forum Name'));
 			return false;
 		}
@@ -602,7 +620,7 @@ class Forum extends Error {
 			is_public=$6
 			WHERE group_id=$7
 			AND group_forum_id=$8',
-					array (strtolower($forum_name),
+					array ($forum_name,
 					       htmlspecialchars($description),
 					       $send_all_posts_to,
 					       $allow_anonymous,
@@ -652,6 +670,10 @@ class Forum extends Error {
 		db_query_params ('DELETE FROM forum_group_list WHERE group_forum_id=$1',
 				 array ($this->getID())) ;
 //echo '5'.db_error();
+		//delete forum's role setting
+		db_query_params ('DELETE FROM role_setting WHERE section_name=$1 AND ref_id=$2',
+				 array ('forum',
+				 $this->getID())) ;
 		db_commit();
 		return true;
 	}
