@@ -106,8 +106,10 @@ class GroupJoinRequest extends Error {
 		}
 
 		// Check if user is already a member of the project
-		$perm =& $this->Group->getPermission( user_get_object($user_id) );
-		if ($perm && is_object($perm) && $perm->isMember()) {
+		$result = db_query_params ('SELECT * FROM user_group WHERE group_id=$1 AND user_id=$2',
+					   array ($this->Group->getID(),
+						  $user_id)) ;
+		if (db_numrows($result)) {
 			$this->setError(_('You are already a member of this project.'));
 			return false;
 		}
