@@ -1,29 +1,28 @@
 <?php
 /**
- * utils.php - Misc utils common to all aspects of the site
+ * FusionForge miscellaneous utils
  *
- * Copyright 1999-2001 (c) VA Linux Systems
+ * Copyright 1999-2001, VA Linux Systems, Inc.
+ * Copyright 2009, Roland Mas
  *
- * @version   $Id$
+ * This file is part of FusionForge.
  *
- * This file is part of GForge.
- *
- * GForge is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * GForge is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * FusionForge is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published
+ * by the Free Software Foundation; either version 2 of the License,
+ * or (at your option) any later version.
+ * 
+ * FusionForge is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GForge; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  US
+ * along with FusionForge; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  */
 
-
 /**
  * removeCRLF() - remove any Carriage Return-Line Feed from a string. 
  * That function is useful to remove the possibility of a CRLF Injection when sending mail
@@ -114,7 +113,7 @@ function util_send_message($to,$subject,$body,$from='',$BCC='',$sendername='',$e
 		$body2 .= "\nBCC: $BCC";
 	}
 	$send_html_email?$type="html":$type="plain";
-	$body2 .= "\nSubject: ".util_encode_mimeheader($subject, $charset).
+	$body2 .= "\n".util_encode_mimeheader("Subject", $subject, $charset).
 		"\nContent-type: text/$type; charset=$charset".
 		"\n\n".
 		util_convert_body($body, $charset);
@@ -156,17 +155,28 @@ function util_encode_mailaddr($email,$name,$charset) {
 /**
  * util_encode_mimeheader() - Encode mimeheader
  *
+ * @param		string	The name of the header (e.g. "Subject")
  * @param		string	The email subject
  * @param		string	The converting charset (like ISO-2022-JP)
  * @return		string	The MIME encoded subject
  *
  */
-function util_encode_mimeheader($str,$charset) {
-	if (!function_exists('mb_convert_encoding')) {
-		return $str;
+function util_encode_mimeheader($headername,$str,$charset) {
+	if (function_exists('mb_internal_encoding') &&
+	    function_exists('mb_encode_mimeheader')) {
+		$x = mb_internal_encoding();
+		mb_internal_encoding("UTF-8");
+		$y = mb_encode_mimeheader($headername . ": " . $str,
+					  $charset, "Q");
+		mb_internal_encoding($x);
+		return $y;
 	}
 
-	return "=?".$charset."?B?".
+	if (!function_exists('mb_convert_encoding')) {
+		return $headername . ": " . $str;
+	}
+
+	return $headername . ": " . "=?".$charset."?B?".
 		base64_encode(mb_convert_encoding(
 			$str,$charset,"UTF-8")).
 		"?=";
@@ -255,9 +265,9 @@ function util_handle_message($id_arr,$subject,$body,$extra_emails='',$extra_jabb
 	if (count($id_arr) < 1) {
 
 	} else {
-		$res=db_query("SELECT user_id, jabber_address,email,jabber_only
-			FROM users WHERE user_id IN (". implode($id_arr,',') .")");
-		$rows=db_numrows($res);
+		$res = db_query_params ('SELECT user_id,jabber_address,email,jabber_only FROM users WHERE user_id = ANY ($1)',
+					array (db_int_array_to_any_clause ($id_arr))) ;
+		$rows = db_numrows($res) ;
 
 		for ($i=0; $i<$rows; $i++) {
 			if (db_result($res, $i, 'user_id') == 100) {
@@ -745,7 +755,7 @@ function ShowResultSet($result,$title='',$linkify=false,$displayHeaders=true,$he
  *
  */
 function validate_email ($address) {
-	return (ereg('^[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+'. '@'. '[-!#$%&\'*+\\/0-9=?A-Z^_`a-z{|}~]+\.' . '[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+$', $address));
+	return (ereg('^[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+'. '@'. '[-!#$%&\'*+\\/0-9=?A-Z^_`a-z{|}~]+\.' . '[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+$', $address) !== false);
 }
 
 /**
@@ -903,6 +913,8 @@ function readfile_chunked($filename, $returnBytes=true) {
     while (!feof($handle)) {
         $buffer = fread($handle, $chunksize);
         echo $buffer;
+	ob_flush() ;
+	flush () ;
         if ($returnBytes) {
             $byteCounter += strlen($buffer);
 		}
