@@ -4,8 +4,6 @@
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  *
- * @version   $Id$
- *
  * This file is part of GForge.
  *
  * GForge is free software; you can redistribute it and/or modify
@@ -25,6 +23,9 @@
 
 function site_admin_header($params) {
 	global $feedback,$HTML;
+	if (!isset($feedback)) {
+		$feedback = '';
+	}
 	session_require(array('group'=>'1','admin_flags'=>'A'));
 	$HTML->header($params);
 	echo html_feedback_top($feedback);
@@ -32,8 +33,16 @@ function site_admin_header($params) {
 
 function site_admin_footer($vals=0) {
 	GLOBAL $HTML, $feedback;
+	if (!isset($feedback)) {
+		$feedback = '';
+	}
 	echo html_feedback_bottom($feedback);
 	$HTML->footer(array());
 }
 
+// Local Variables:
+// mode: php
+// c-file-style: "bsd"
+// End:
+
 ?>
